{ nix-config, pkgs, ... }:
let
  pwdcmd = "${nix-config.packages.x86_64-linux.rbw-latest}/bin/rbw";
in
{
  accounts.email = {
    maildirBasePath = "/home/emenel/.maildir";
    accounts = {
      "matt@emenel.ca" = {
        address = "matt@emenel.ca";
        realName = "Matt Nish-Lapidus";
        primary = true;
        mu.enable = true;
        mbsync = {
          enable = true;
          create = "both";
          extraConfig.channel = {
            CopyArrivalDate = true;
            Sync = "All";
            Expunge = "Both";
          };
        };
        msmtp.enable = true;
        flavor = "fastmail.com";
        passwordCommand = "${pwdcmd} get mu4e-fastmail";
        imapnotify = {
          enable = true;
          boxes = [ "Inbox" ];
          onNotify = "${pkgs.isync}/bin/mbsync -a";
        };
      };

      "admin@studyoftime.org" = {
        address = "admin@studyoftime.org";
        realName = "ISST Web Admin";
        mu.enable = true;
        mbsync = {
          enable = true;
          create = "both";
          extraConfig.channel = {
            CopyArrivalDate = true;
            Expunge = "Both";
          };
        };
        msmtp.enable = true;
        passwordCommand = "${pwdcmd} get admin@studyoftime";
        imap.host = "imap.dreamhost.com";
        smtp.host = "imap.dreamhost.com";
        userName = "admin@studyoftime.org";
      };
    };
  };

  services.imapnotify = {
    enable = true;
    package = pkgs.goimapnotify;
    path = [ pkgs.mu pkgs.isync pkgs.goimapnotify nix-config.packages.x86_64-linux.rbw-latest ];
  };

  programs = {
    mu.enable = true;
    mbsync = {
      enable = true;
    };
    msmtp.enable = true;
    thunderbird = {
      enable = true;
      profiles.emenel = {
        isDefault = true;
      };
    };
  };
}
